# ProtLoc-mexl
This project provides a pipeline for fast construction of subcellular localization prediction and model interpretation, with 42 amino acid feature characterization algorithms and GO feature extraction based on Doc2Vec. In addition, two random forest models for protein localization prediction are also provided.

As the manuscript is still under review, we have not fully released the core code and pre-trained models of ProtLoc-Mex1. If you need the core code, please contact the author at 1024226968@qq.com by email.